/****************************************************************************
** Meta object code from reading C++ file 'kshortcutsdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kxmlgui-6.27.0/src/kshortcutsdialog_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kshortcutsdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24KShortcutsEditorDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto KShortcutsEditorDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN24KShortcutsEditorDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KShortcutsEditorDelegate",
        "shortcutChanged",
        "",
        "QKeySequence",
        "QModelIndex",
        "hiddenBySearchLine",
        "QTreeWidgetItem*",
        "itemActivated",
        "index",
        "itemCollapsed",
        "stealShortcut",
        "seq",
        "QAction*",
        "action"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shortcutChanged'
        QtMocHelpers::SignalData<void(const QKeySequence &, const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Slot 'hiddenBySearchLine'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'itemActivated'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 8 },
        }}),
        // Slot 'itemCollapsed'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 8 },
        }}),
        // Slot 'stealShortcut'
        QtMocHelpers::SlotData<void(const QKeySequence &, QAction *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KShortcutsEditorDelegate, qt_meta_tag_ZN24KShortcutsEditorDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KShortcutsEditorDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<KExtendableItemDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KShortcutsEditorDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KShortcutsEditorDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24KShortcutsEditorDelegateE_t>.metaTypes,
    nullptr
} };

void KShortcutsEditorDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KShortcutsEditorDelegate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shortcutChanged((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 1: _t->hiddenBySearchLine((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->itemActivated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 3: _t->itemCollapsed((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 4: _t->stealShortcut((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KShortcutsEditorDelegate::*)(const QKeySequence & , const QModelIndex & )>(_a, &KShortcutsEditorDelegate::shortcutChanged, 0))
            return;
    }
}

const QMetaObject *KShortcutsEditorDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KShortcutsEditorDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24KShortcutsEditorDelegateE_t>.strings))
        return static_cast<void*>(this);
    return KExtendableItemDelegate::qt_metacast(_clname);
}

int KShortcutsEditorDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KExtendableItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KShortcutsEditorDelegate::shortcutChanged(const QKeySequence & _t1, const QModelIndex & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN18TabConnectedWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TabConnectedWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18TabConnectedWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabConnectedWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabConnectedWidget, qt_meta_tag_ZN18TabConnectedWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabConnectedWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TabConnectedWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TabConnectedWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TabConnectedWidgetE_t>.metaTypes,
    nullptr
} };

void TabConnectedWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabConnectedWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TabConnectedWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabConnectedWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TabConnectedWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int TabConnectedWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ShortcutEditWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ShortcutEditWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18ShortcutEditWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShortcutEditWidget",
        "keySequenceChanged",
        "",
        "QKeySequence",
        "stealShortcut",
        "seq",
        "QAction*",
        "action",
        "setKeySequence",
        "activeSeq",
        "defaultToggled",
        "setCustom"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'keySequenceChanged'
        QtMocHelpers::SignalData<void(const QKeySequence &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'stealShortcut'
        QtMocHelpers::SignalData<void(const QKeySequence &, QAction *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'setKeySequence'
        QtMocHelpers::SlotData<void(const QKeySequence &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Slot 'defaultToggled'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setCustom'
        QtMocHelpers::SlotData<void(const QKeySequence &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShortcutEditWidget, qt_meta_tag_ZN18ShortcutEditWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShortcutEditWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<TabConnectedWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ShortcutEditWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ShortcutEditWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ShortcutEditWidgetE_t>.metaTypes,
    nullptr
} };

void ShortcutEditWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ShortcutEditWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->keySequenceChanged((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 1: _t->stealShortcut((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2]))); break;
        case 2: _t->setKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 3: _t->defaultToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setCustom((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ShortcutEditWidget::*)(const QKeySequence & )>(_a, &ShortcutEditWidget::keySequenceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ShortcutEditWidget::*)(const QKeySequence & , QAction * )>(_a, &ShortcutEditWidget::stealShortcut, 1))
            return;
    }
}

const QMetaObject *ShortcutEditWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShortcutEditWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ShortcutEditWidgetE_t>.strings))
        return static_cast<void*>(this);
    return TabConnectedWidget::qt_metacast(_clname);
}

int ShortcutEditWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TabConnectedWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ShortcutEditWidget::keySequenceChanged(const QKeySequence & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ShortcutEditWidget::stealShortcut(const QKeySequence & _t1, QAction * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN22KShortcutSchemesEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto KShortcutSchemesEditor::qt_create_metaobjectdata<qt_meta_tag_ZN22KShortcutSchemesEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KShortcutSchemesEditor",
        "shortcutsSchemeChanged",
        "",
        "newScheme",
        "deleteScheme",
        "exportShortcutsScheme",
        "importShortcutsScheme",
        "saveAsDefaultsForScheme"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shortcutsSchemeChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'newScheme'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteScheme'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'exportShortcutsScheme'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importShortcutsScheme'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveAsDefaultsForScheme'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KShortcutSchemesEditor, qt_meta_tag_ZN22KShortcutSchemesEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KShortcutSchemesEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QGroupBox::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KShortcutSchemesEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KShortcutSchemesEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KShortcutSchemesEditorE_t>.metaTypes,
    nullptr
} };

void KShortcutSchemesEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KShortcutSchemesEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shortcutsSchemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newScheme(); break;
        case 2: _t->deleteScheme(); break;
        case 3: _t->exportShortcutsScheme(); break;
        case 4: _t->importShortcutsScheme(); break;
        case 5: _t->saveAsDefaultsForScheme(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KShortcutSchemesEditor::*)(const QString & )>(_a, &KShortcutSchemesEditor::shortcutsSchemeChanged, 0))
            return;
    }
}

const QMetaObject *KShortcutSchemesEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KShortcutSchemesEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KShortcutSchemesEditorE_t>.strings))
        return static_cast<void*>(this);
    return QGroupBox::qt_metacast(_clname);
}

int KShortcutSchemesEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGroupBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KShortcutSchemesEditor::shortcutsSchemeChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
